Python TBX - Toolbox Library - AWS Tools
========================================


About
-----

Python Toolbox aka TBX is a collection of very different tools created over the years to simplify my coding.
As a library, this has no purpose by itself and should be used by other projects.

***tbx.aws*** - this specific project relates to Amazon Web Services, and specific wrappers around boto3 library for handling EC2  and Route53 features more easily.

Project url : https://github.com/ronhanson/python-tbx-aws



Description
-----------

The library contains several unrelated tool collections :


- **tbx.aws** - contains AWS EC2 and Route53 wrappers around boto3 library


Usage
-----

Just look at the code as it is commented for your to understand its usage.

No big doc made yet. This is more of a personal collection of snippets and tools.

But if somebody is interested or requests it, I will make a better doc.


Compatibility
-------------

This libraries are used most on Linux and OSX systems, but plenty of functions may work on windows.

This libraries are compatibles with Python 3.3+.

Mainly tested on 3.6.


Author & Licence
----------------

Copyright (c) 2010-2015 Ronan Delacroix

This program is released under MIT Licence. Feel free to use it or part of it anywhere you want.
